@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2004-02-22 15:46+0900\n"
+"POT-Creation-Date: 2004-08-07 01:06+0900\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -16,7 +16,7 @@ msgstr ""
 "Content-Type: text/plain; charset=CHARSET\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: src/cellrendererebook.c:161 src/mainwindow.c:984
+#: src/cellrendererebook.c:161 src/mainwindow.c:985
 msgid "Text"
 msgstr ""
 
@@ -53,28 +53,28 @@ msgid "offset"
 msgstr ""
 
 #: src/eb.c:375 src/eb.c:442 src/mainmenu.c:478 src/mainwindow.c:482
-#: src/mainwindow.c:1137
+#: src/mainwindow.c:1138
 msgid "Automatic Search"
 msgstr ""
 
-#: src/eb.c:380 src/eb.c:446 src/mainmenu.c:486 src/mainwindow.c:1148
+#: src/eb.c:380 src/eb.c:446 src/mainmenu.c:486 src/mainwindow.c:1149
 msgid "Exactword Search"
 msgstr ""
 
-#: src/eb.c:386 src/eb.c:450 src/mainmenu.c:492 src/mainwindow.c:1160
+#: src/eb.c:386 src/eb.c:450 src/mainmenu.c:492 src/mainwindow.c:1161
 msgid "Forward Search"
 msgstr ""
 
-#: src/eb.c:392 src/eb.c:454 src/mainmenu.c:499 src/mainwindow.c:1172
+#: src/eb.c:392 src/eb.c:454 src/mainmenu.c:499 src/mainwindow.c:1173
 msgid "Backward Search"
 msgstr ""
 
-#: src/eb.c:398 src/eb.c:458 src/mainmenu.c:506 src/mainwindow.c:1184
+#: src/eb.c:398 src/eb.c:458 src/mainmenu.c:506 src/mainwindow.c:1185
 msgid "Keyword Search"
 msgstr ""
 
 #: src/eb.c:404 src/eb.c:462 src/mainmenu.c:513 src/mainwindow.c:490
-#: src/mainwindow.c:491 src/mainwindow.c:1196
+#: src/mainwindow.c:491 src/mainwindow.c:1197
 msgid "Multiword Search"
 msgstr ""
 
@@ -83,18 +83,19 @@ msgid "Full Text Search"
 msgstr ""
 
 #: src/eb.c:427 src/eb.c:480 src/mainmenu.c:547 src/mainwindow.c:481
-#: src/mainwindow.c:499 src/mainwindow.c:500 src/mainwindow.c:1223
+#: src/mainwindow.c:499 src/mainwindow.c:500 src/mainwindow.c:1224
 #: src/preference.c:94
 msgid "Internet Search"
 msgstr ""
 
 #: src/eb.c:431 src/eb.c:484 src/grep.c:77 src/mainmenu.c:554
-#: src/mainwindow.c:507 src/mainwindow.c:508 src/mainwindow.c:1237
+#: src/mainwindow.c:507 src/mainwindow.c:508 src/mainwindow.c:1238
 #: src/preference.c:88
 msgid "File Search"
 msgstr ""
 
 #. Cancelable
+#. Non-cancelable
 #: src/eb.c:1615 src/eb.c:1619
 msgid "Fulltext search"
 msgstr ""
@@ -180,7 +181,7 @@ msgstr ""
 msgid "Go to next hit list."
 msgstr ""
 
-#: src/mainmenu.c:520 src/mainwindow.c:1208
+#: src/mainmenu.c:520 src/mainwindow.c:1209
 msgid "Fulltext Search"
 msgstr ""
 
@@ -387,7 +388,7 @@ msgid "Search In Popup"
 msgstr ""
 
 #. if(selection_mode == SELECTION_POPUP)
-#. 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
+#. gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
 #. Dump
 #: src/mainmenu.c:954
 msgid "Dump"
@@ -440,59 +441,59 @@ msgstr ""
 msgid "Help will be shown in external web browser."
 msgstr ""
 
-#: src/mainwindow.c:746
+#: src/mainwindow.c:748
 msgid "Search Word"
 msgstr ""
 
-#: src/mainwindow.c:767
+#: src/mainwindow.c:768
 msgid ""
 "Type word here. You can type multiple space-separated words for keyword "
 "search. For file search, specify words or regular expression."
 msgstr ""
 
-#: src/mainwindow.c:783 src/multi.c:294
+#: src/mainwindow.c:784 src/multi.c:294
 msgid "Start search"
 msgstr ""
 
-#: src/mainwindow.c:809
+#: src/mainwindow.c:810
 msgid "Select search method."
 msgstr ""
 
-#: src/mainwindow.c:835
+#: src/mainwindow.c:836
 msgid "When enabled, X selection is searched automatically"
 msgstr ""
 
-#: src/mainwindow.c:853
+#: src/mainwindow.c:854
 msgid ""
 "When enabled, result of X selection search will be shown in popup window"
 msgstr ""
 
-#: src/mainwindow.c:869
+#: src/mainwindow.c:870
 msgid "Previous Item"
 msgstr ""
 
-#: src/mainwindow.c:881
+#: src/mainwindow.c:882
 msgid "Next Item"
 msgstr ""
 
-#: src/mainwindow.c:896
+#: src/mainwindow.c:897
 msgid "show next in history"
 msgstr ""
 
-#: src/mainwindow.c:907
+#: src/mainwindow.c:908
 msgid "show previous in history"
 msgstr ""
 
-#: src/mainwindow.c:993
+#: src/mainwindow.c:994
 msgid "Candidate"
 msgstr ""
 
-#. 						rp->heading = strdup(_("menu"));
+#. rp->heading = strdup(_("menu"));
 #: src/menu.c:70
 msgid "menu"
 msgstr ""
 
-#. 						rp->heading = strdup(_("copyright"));
+#. rp->heading = strdup(_("copyright"));
 #: src/menu.c:130
 msgid "copyright"
 msgstr ""
@@ -587,6 +588,7 @@ msgstr ""
 #: src/pref_dictgroup.c:1123 src/pref_dictgroup.c:1125
 #: src/pref_dictgroup.c:1128 src/pref_dictgroup.c:1130
 #: src/pref_dictgroup.c:1200 src/pref_dictgroup.c:1525
+#, c-format
 msgid "Sample"
 msgstr ""
 
@@ -693,7 +695,7 @@ msgstr ""
 msgid "Choose.."
 msgstr ""
 
-#. 	gtk_container_add(GTK_CONTAINER(frame), vbox);
+#. gtk_container_add(GTK_CONTAINER(frame), vbox);
 #: src/pref_external.c:80
 msgid "Play sound internally"
 msgstr ""
@@ -911,8 +913,8 @@ msgid ""
 "not be looked up."
 msgstr ""
 
-#. 	gtk_box_pack_start (GTK_BOX(vbox)
-#. 			    , hbox,FALSE, FALSE, 0);
+#. gtk_box_pack_start (GTK_BOX(vbox)
+#. , hbox,FALSE, FALSE, 0);
 #: src/pref_selection.c:130
 msgid "Maximum chars for automatic lookup"
 msgstr ""
@@ -923,8 +925,8 @@ msgid ""
 "will not be looked up."
 msgstr ""
 
-#. 	gtk_box_pack_start (GTK_BOX(vbox)
-#. 			    , hbox,FALSE, FALSE, 0);
+#. gtk_box_pack_start (GTK_BOX(vbox)
+#. , hbox,FALSE, FALSE, 0);
 #: src/pref_selection.c:161
 msgid "Popup window size"
 msgstr ""
@@ -1093,8 +1095,8 @@ msgstr ""
 msgid "Show Next Text"
 msgstr ""
 
-#. 	{ N_("Toggle Selection Search"), toggle_auto},
-#. 	{ N_("Toggle Popup"), toggle_popup},
+#. { N_("Toggle Selection Search"), toggle_auto},
+#. { N_("Toggle Popup"), toggle_popup},
 #: src/pref_shortcut.c:95
 msgid "Show Help"
 msgstr ""
